#include <kapplication.h>
#include <kcmdlineargs.h>
#include <kfileitem.h>
#include <qfileinfo.h>
#include <qdir.h>

void
analyzeFile(const QString& url, const QFileInfo& fi) {
    // Then create a new KFileMetaInfo object
    KFileMetaInfo info( KURL::fromPathOrURL( url ), QString::null,
        KFileMetaInfo::Everything);
    // See: http://developer.kde.org/documentation/library/cvs-api/kdelibs-apidocs/kio/kio/html/classKFileMetaInfo.html

    printf(" <file uri='%s' mtime='%i'>\n", (const char*)url.utf8(),
        fi.lastModified().toTime_t());
    // and process the metadata:
    if (!info.isEmpty()) {
        QStringList sk(info.supportedKeys());
        QStringList::Iterator it;
        for ( it = sk.begin(); it != sk.end(); ++it ) {
            QString value = info.value(*it).toString();
            if (!value.isNull() && value.length()) {
                printf("  <value name='%s'>%s</value>\n",
                    (const char*)(*it).utf8(),
                    (const char*)value.utf8());
            }
        }
        if (!info.mimeType().isNull()) {
                printf("  <value name='mimetype'>%s</value>\n",
                    (const char*)info.mimeType().utf8());
        }
    }
    printf(" </file>\n");
};

void
analyze(const QString& url) {
    QFileInfo f(url);
    if (f.isFile()) {
        analyzeFile(url, f);
    } else if (f.isDir()) {
        QDir d(url);
        QStringList l(d.entryList());
        for (uint i=0; i<l.size(); ++i) {
            if (l[i] != "." && l[i] != "..") {
                analyze(d.filePath(l[i]));
            }
        }
    }
}

int main( int argc, char **argv ) {
    KCmdLineArgs::init(1, argv, "ktestcase", "ktestcase", "ktestcase", "0");
    KApplication a(false, false);

    printf("<?xml version='1.0' encoding='UTF-8'?>\n<metadata>\n");
    for (int i=1; i<argc; ++i) {
        analyze(argv[i]);
    }
    printf("</metadata>\n");
    return 0;
}
